repo
stringlengths
7
90
file_url
stringlengths
81
315
file_path
stringlengths
4
228
content
stringlengths
0
32.8k
language
stringclasses
1 value
license
stringclasses
7 values
commit_sha
stringlengths
40
40
retrieved_at
stringdate
2026-01-04 14:38:15
2026-01-05 02:33:18
truncated
bool
2 classes
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/tinygrad/engine/jit.py
tinygrad_repo/tinygrad/engine/jit.py
from typing import TypeVar, Generic, Callable, cast, Any import functools, collections from tinygrad.tensor import Tensor from tinygrad.helpers import flatten, merge_dicts, DEBUG, Context, BEAM, getenv, colored, JIT, JIT_BATCH_SIZE, dedup, partition, unwrap from tinygrad.device import Buffer, Compiled, Device, MultiBuf...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/tinygrad/engine/__init__.py
tinygrad_repo/tinygrad/engine/__init__.py
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/tinygrad/engine/realize.py
tinygrad_repo/tinygrad/engine/realize.py
from typing import cast, Generator, Callable import time, pprint, random, itertools, math from dataclasses import dataclass, replace, field from tinygrad.helpers import all_same, colored, DEBUG, GlobalCounters, ansilen, BEAM, NOOPT, all_int, CAPTURING, Metadata, TRACEMETA, TracingKey from tinygrad.helpers import DEVECT...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/tinygrad/shape/shapetracker.py
tinygrad_repo/tinygrad/shape/shapetracker.py
# ShapeTracker allows movement operations to a buffer that don't require a copy to be made. from __future__ import annotations from dataclasses import dataclass import functools from typing import Callable from tinygrad.helpers import merge_dicts, getenv from tinygrad.shape.view import View, unravel from tinygrad.uop.s...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/tinygrad/shape/view.py
tinygrad_repo/tinygrad/shape/view.py
from __future__ import annotations import functools, operator, itertools from dataclasses import dataclass from typing import cast, Sequence from tinygrad.dtype import dtypes from tinygrad.uop.ops import resolve, UOp, Variable, sint, smax, smin, sint_to_uop, Ops, ssimplify from tinygrad.helpers import prod, all_int, ar...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/tinygrad/shape/__init__.py
tinygrad_repo/tinygrad/shape/__init__.py
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_tiny.py
tinygrad_repo/test/test_tiny.py
# basic self-contained tests of the external functionality of tinygrad import unittest, random from tinygrad import Tensor, Context, Variable, TinyJit, dtypes, Device, nn from tinygrad.helpers import IMAGE, CI, getenv class TestTiny(unittest.TestCase): # *** basic functionality *** def test_const(self): cons...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_tensor_uop.py
tinygrad_repo/test/test_tensor_uop.py
#!/usr/bin/env python import numpy as np import unittest from tinygrad import Tensor, Device, dtypes from tinygrad.engine.realize import run_schedule from tinygrad.uop.ops import Ops, UOp, UPat class TestTensorUOp(unittest.TestCase): def test_fromcpu_shape_tracker(self): def helper(a: np.ndarray): print(a....
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_uops.py
tinygrad_repo/test/test_uops.py
from typing import Optional, Any import unittest, math import numpy as np from tinygrad.shape.shapetracker import ShapeTracker from tinygrad.shape.view import View # noqa F401 from tinygrad.tensor import Tensor, _to_np_dtype from tinygrad.helpers import CI, DEBUG, getenv, Timing from tinygrad.dtype import dtypes, DType...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_remote.py
tinygrad_repo/test/test_remote.py
import numpy as np, unittest, string from hypothesis import given, strategies as st from tinygrad import Device, Tensor, TinyJit, dtypes from tinygrad.runtime.ops_remote import RemoteDevice, parse_hosts from tinygrad.runtime.graph.remote import RemoteGraph from tinygrad.helpers import LazySeq, all_same, Context def mu...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_interop.py
tinygrad_repo/test/test_interop.py
#!/usr/bin/env python import unittest import torch import numpy as np from tinygrad.helpers import getenv, CI from tinygrad.tensor import Tensor from tinygrad.device import Device from tinygrad.dtype import _from_torch_dtype, _to_torch_dtype MOCKGPU = getenv("MOCKGPU") @unittest.skipIf(Device.DEFAULT not in ["METAL"...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_transcendental.py
tinygrad_repo/test/test_transcendental.py
import unittest from tinygrad import Tensor, Device, dtypes from tinygrad.tensor import _to_np_dtype from tinygrad.helpers import Context, getenv, CI, OSX from test.test_schedule import check_schedule from test.test_dtype_alu import ht, dtypes_float from tinygrad.device import is_dtype_supported import numpy as np impo...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_tensor.py
tinygrad_repo/test/test_tensor.py
import subprocess import numpy as np import torch import unittest, copy, mmap, random, math, array from tinygrad import Tensor, Device, dtypes from tinygrad.tensor import _METADATA from tinygrad.helpers import getenv, temp, mv_address, RANGEIFY from extra.gradcheck import numerical_jacobian, jacobian, gradcheck from hy...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
true
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_opt_gemm.py
tinygrad_repo/test/test_opt_gemm.py
import numpy as np import unittest from tinygrad import Tensor from tinygrad.helpers import get_single_element from tinygrad.codegen.opt import Opt, OptOps from tinygrad.engine.realize import CompiledRunner, ExecItem, get_program class TestOptGemm(unittest.TestCase): @classmethod def setUpClass(cls): N = 64 ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_tensor_variable.py
tinygrad_repo/test/test_tensor_variable.py
import unittest import numpy as np from tinygrad import Tensor, Variable class TestTensorVariable(unittest.TestCase): def test_add_tvar(self): vv = Variable("a", 0, 10).bind(1) ret = (Tensor(vv) + 3).item() assert ret == 4 def test_inner_tvar_node(self): vv = Variable("w", 0, 10).bind(2) ret =...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_multitensor.py
tinygrad_repo/test/test_multitensor.py
import unittest, functools, random from tinygrad import Tensor, Device, nn, GlobalCounters, TinyJit, dtypes, Variable from tinygrad.device import is_dtype_supported from tinygrad.uop.ops import Ops, UOp from tinygrad.helpers import CI, getenv, prod, Context, RANGEIFY from tinygrad.nn.state import get_parameters, get_st...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
true
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_dtype_alu.py
tinygrad_repo/test/test_dtype_alu.py
import unittest, operator, math from tinygrad import Tensor, dtypes, Device from tinygrad.dtype import DType, truncate from tinygrad.helpers import CI, getenv from tinygrad.tensor import _to_np_dtype from tinygrad.device import is_dtype_supported from tinygrad.runtime.ops_python import from_storage_scalar from tinygrad...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_memory_planner.py
tinygrad_repo/test/test_memory_planner.py
import unittest from tinygrad import dtypes, Device from tinygrad.device import Buffer from tinygrad.engine.memory import _internal_memory_planner global_map = {} def b(i, base=None, offset=0, pin=False, size=16): global global_map if i in global_map: return global_map[i] global_map[i] = Buffer(Device.DEFAULT, s...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_zero_copy.py
tinygrad_repo/test/test_zero_copy.py
import unittest from tinygrad import Tensor, Device import time def time_tensor_numpy(out:Tensor): times = [] for _ in range(5): st = time.perf_counter() out.uop.base.realized.as_buffer(allow_zero_copy=True) et = time.perf_counter() - st times.append(et) return min(times) N = 4096 class TestZero...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_assign.py
tinygrad_repo/test/test_assign.py
#!/usr/bin/env python import unittest import numpy as np from tinygrad import dtypes, Tensor, TinyJit, GlobalCounters, Variable from tinygrad.device import is_dtype_supported from tinygrad.helpers import temp N = 200 # has to be bigger than the cache to fail class TestAssign(unittest.TestCase): def test_simple_ass...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_const_folding.py
tinygrad_repo/test/test_const_folding.py
import unittest, itertools, math from tinygrad import Tensor, Device, dtypes from tinygrad.dtype import DType, ConstType from tinygrad.uop.ops import Ops, UOp from tinygrad.codegen import full_rewrite_to_sink from tinygrad.device import is_dtype_supported import numpy as np from test.helpers import not_support_multi_de...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_optim.py
tinygrad_repo/test/test_optim.py
import numpy as np import torch import unittest from tinygrad import Tensor, Device, dtypes from tinygrad.nn.optim import Adam, SGD, AdamW, Muon from tinygrad.helpers import CI from tinygrad.device import is_dtype_supported from extra.torch_muon import SingleDeviceMuon as TorchMuon np.random.seed(1337) x_init = np.ran...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_quantize_onnx.py
tinygrad_repo/test/test_quantize_onnx.py
# ruff: noqa: E501 import numpy as np import unittest from dataclasses import replace from tinygrad import Tensor, Context, Device, dtypes from tinygrad.uop.ops import Ops from tinygrad.codegen.opt import Opt, OptOps from tinygrad.engine.realize import CompiledRunner, ExecItem, lower_schedule_item, get_program N = 512...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_subbuffer.py
tinygrad_repo/test/test_subbuffer.py
import unittest from tinygrad import Device, dtypes, Tensor from tinygrad.device import Buffer from tinygrad.helpers import Context from test.helpers import REAL_DEV @unittest.skipUnless(hasattr(Device[Device.DEFAULT].allocator, "_offset"), "subbuffer not supported") class TestSubBuffer(unittest.TestCase): def setUp...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_rangeify.py
tinygrad_repo/test/test_rangeify.py
import unittest from tinygrad import Tensor, nn from tinygrad.helpers import RANGEIFY, Context, GlobalCounters from tinygrad.uop.ops import UOp @unittest.skipIf(RANGEIFY<1, "tests only for RANGEIFY") class TestRangeifyAssign(unittest.TestCase): def test_assign_permuted(self): A = Tensor.empty(4, 4, dtype='int') ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_stunning.py
tinygrad_repo/test/test_stunning.py
import unittest from tinygrad import nn, Tensor, Variable, Context, Device from tinygrad.helpers import trange class Model: def __init__(self): self.layer = nn.Linear(28*28, 10) def __call__(self, x:Tensor) -> Tensor: return self.layer(x.flatten(1)) class TestStunning(unittest.TestCase): def test_indexing_varia...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_outerworld_range.py
tinygrad_repo/test/test_outerworld_range.py
import unittest from tinygrad import Tensor, nn, Variable, UOp # outerworld range should support three things # 1. full optimizer steps (test_model_bound_range) # 2. gradient accumulation (you want to end the range before running the optimizer) # 3. stacked linear layers class Model: def __init__(self): self.w = nn...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_dtype.py
tinygrad_repo/test/test_dtype.py
import unittest, math import numpy as np import torch from typing import Any, List from tinygrad.device import is_dtype_supported from tinygrad.helpers import getenv, DEBUG, CI from tinygrad.dtype import DType, DTYPES_DICT, least_upper_dtype, fp8_to_float, float_to_fp8, _to_np_dtype, _to_torch_dtype, truncate from tiny...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_symbolic_jit.py
tinygrad_repo/test/test_symbolic_jit.py
import unittest from test.helpers import assert_jit_cache_len from tinygrad import Variable, Tensor, TinyJit from tinygrad.helpers import RANGEIFY import numpy as np class TestSymbolicJit(unittest.TestCase): def test_plus1(self): def f(a): return (a+1).realize() jf = TinyJit(f) a = Tensor.rand(3, 10) ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_randomness.py
tinygrad_repo/test/test_randomness.py
import unittest, math from functools import partial from tinygrad import nn, dtypes, Tensor, Device, TinyJit, Variable from tinygrad.helpers import getenv, CI, OSX from tinygrad.device import is_dtype_supported from tinygrad.engine.realize import lower_schedule, CompiledRunner from tinygrad.renderer.ptx import PTXRend...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_to_numpy.py
tinygrad_repo/test/test_to_numpy.py
from tinygrad.tensor import Tensor import numpy as np import pickle import unittest class TestToNumpy(unittest.TestCase): def test_numpy_is_numpy(self): output = Tensor.ones((1, 3, 4096)).realize().numpy() new = np.copy(output) print(type(new)) serialized = pickle.dumps(new) out = pickle.loads(se...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_jit.py
tinygrad_repo/test/test_jit.py
#!/usr/bin/env python import unittest, functools import numpy as np from hypothesis import given, settings, strategies as strat from test.helpers import assert_jit_cache_len, not_support_multi_device, REAL_DEV from tinygrad.tensor import Tensor from tinygrad.engine.jit import TinyJit, GraphRunner, MultiGraphRunner, gr...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_renderer_failures.py
tinygrad_repo/test/test_renderer_failures.py
import unittest from typing import List, cast import numpy as np from tinygrad.device import Buffer, Device, is_dtype_supported from tinygrad.dtype import dtypes, ConstType from tinygrad.engine.realize import CompiledRunner from tinygrad.helpers import dedup, flatten, prod from tinygrad.renderer.cstyle import CStyleLan...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_graph.py
tinygrad_repo/test/test_graph.py
import numpy as np import functools, unittest, ctypes from tinygrad.device import Device, Buffer from tinygrad.tensor import Tensor, _to_np_dtype from tinygrad.helpers import Context, CI, dedup, from_mv from tinygrad.dtype import dtypes from tinygrad.engine.jit import MultiGraphRunner from tinygrad.engine.realize impo...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/helpers.py
tinygrad_repo/test/helpers.py
import time, struct from typing import Any, Callable import numpy as np from tinygrad import Tensor, dtypes, Device from tinygrad.uop.ops import UOp, Ops from tinygrad.tensor import _to_np_dtype from tinygrad.engine.realize import Runner from tinygrad.dtype import DType from tinygrad.nn.state import get_parameters from...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_opts.py
tinygrad_repo/test/test_opts.py
import unittest from tinygrad import Tensor, Device from tinygrad.helpers import RANGEIFY, CPU_LLVM from tinygrad.codegen.opt import Opt, OptOps from tinygrad.engine.realize import get_program @unittest.skipIf(RANGEIFY>0, "arg is partial contig in rangeify") class TestOpts(unittest.TestCase): def test_opt_upcast(sel...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_kernel_cache.py
tinygrad_repo/test/test_kernel_cache.py
#!/usr/bin/env python import unittest from tinygrad.tensor import Tensor from tinygrad import Device class TestKernelCache(unittest.TestCase): def test_kernel_cache_in_action(self): if Device.DEFAULT not in ["CPU"]: self.skipTest("No custom kernel cache is implemented") unique_const = 0.6765677269 ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_ops.py
tinygrad_repo/test/test_ops.py
import time, math, unittest, functools, platform, warnings import numpy as np from typing import List, Callable import torch from tinygrad.helpers import getenv, IMAGE, DEBUG, CI, Context, TRANSCENDENTAL, CPU_LLVM, AMD_LLVM, RANGEIFY, OSX from tinygrad import Tensor, Device, dtypes from tinygrad.tensor import _to_np_dt...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
true
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_compile_failures.py
tinygrad_repo/test/test_compile_failures.py
import unittest, io from contextlib import redirect_stdout from tinygrad import Tensor, dtypes, Device from tinygrad.helpers import OSX, CPU_LLVM from tinygrad.engine.realize import lower_schedule from tinygrad.device import is_dtype_supported from tinygrad.engine.realize import get_program class TestCompileFailures(u...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_method_cache.py
tinygrad_repo/test/test_method_cache.py
import unittest from tinygrad import Tensor, Device, Variable from examples.gpt2 import Transformer from tinygrad.nn.state import get_state_dict class TestMethodCache(unittest.TestCase): def setUp(self): self.backup_compiler = Device[Device.DEFAULT].compiler.compile_cached def tearDown(self): Device[Device...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/__init__.py
tinygrad_repo/test/__init__.py
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_linearizer_dumb.py
tinygrad_repo/test/test_linearizer_dumb.py
# ruff: noqa: E501 # tests where the Linearizer is doing something dumb # like test_linearizer_failures, but they don't have to fail import unittest from tinygrad import Device, dtypes from tinygrad.device import is_dtype_supported from tinygrad.uop.ops import UOp, Ops, AxisType, KernelInfo from tinygrad.shape.shapetr...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_fusion_op.py
tinygrad_repo/test/test_fusion_op.py
import unittest import time import numpy as np from tinygrad import Tensor, dtypes from tinygrad.engine.realize import lower_schedule_item, run_schedule class TestFusionOp(unittest.TestCase): def test_contiguous_add(self): def test(contig=False): bt = Tensor(np.arange(16), dtype=dtypes.float32).reshape(4,4...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_schedule.py
tinygrad_repo/test/test_schedule.py
# this will be the new test_ops for the next level # schedule confirms the right things are capable of fusing # NOTE: this has overlap with external_test_opt.py import unittest import numpy as np import functools from typing import cast from hypothesis import assume, given, settings, strategies as strat from tinygrad...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
true
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_symbolic_ops.py
tinygrad_repo/test/test_symbolic_ops.py
import unittest from tinygrad import Tensor, Variable, GlobalCounters from tinygrad.shape.shapetracker import View from tinygrad.uop.ops import sym_infer from tinygrad.dtype import dtypes from tinygrad.device import is_dtype_supported from examples.gpt2 import Attention import numpy as np class TestSymbolicOps(unittes...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_nn.py
tinygrad_repo/test/test_nn.py
#!/usr/bin/env python import unittest import numpy as np import torch from tinygrad import Tensor, Device, TinyJit, dtypes from tinygrad.uop.ops import Ops from tinygrad.helpers import GlobalCounters, CI, Context from tinygrad.nn import Conv1d, ConvTranspose1d, Conv2d, ConvTranspose2d, Linear, Embedding from tinygrad.n...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_jit_cases.py
tinygrad_repo/test/test_jit_cases.py
import unittest from tinygrad import TinyJit, Tensor # The JIT functions as a "capturing" JIT. # Whatever kernels ran in the JIT the second run through the function will be the kernels that will run from then on. # Explicit inputs to the function are updated in the JIT graph to the new inputs. # JITs have four tensor...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_pickle.py
tinygrad_repo/test/test_pickle.py
import unittest, pickle, types import numpy as np from tinygrad import Tensor, TinyJit, Variable, dtypes from tinygrad.helpers import GlobalCounters, ContextVar, Context from tinygrad.uop.ops import PatternMatcher, UPat, UOp, Ops class TestPickle(unittest.TestCase): def test_pickle_code_object(self): y = lambda ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_edgecases.py
tinygrad_repo/test/test_edgecases.py
# end to end tests of tinygrad that you think might be edge cases. # using the documentation, write code you think should work. # you can compare the outputs to torch or numpy, or just tinygrad assert/raise while doing things that should be valid # i'm not interested in tests that currently pass, i'm only interested i...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_uop_graph.py
tinygrad_repo/test/test_uop_graph.py
from typing import List import unittest, pytest from tinygrad import dtypes, Variable from tinygrad.dtype import AddrSpace from tinygrad.helpers import DEBUG, Context from tinygrad.uop.ops import Ops, UOp, UPat, PatternMatcher, track_rewrites, graph_rewrite, GroupOp, KernelInfo from tinygrad.uop.symbolic import sym fro...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
true
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_setitem.py
tinygrad_repo/test/test_setitem.py
import unittest import random from os import getenv from tinygrad import Tensor, TinyJit, Variable, dtypes from tinygrad.helpers import Context import numpy as np class TestSetitem(unittest.TestCase): def test_simple_setitem(self): cases = ( ((6,6), (slice(2,4), slice(3,5)), Tensor.ones(2,2)), ((6,6)...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_profiler.py
tinygrad_repo/test/test_profiler.py
import unittest, struct, contextlib, statistics, time, gc from tinygrad import Device, Tensor, dtypes, TinyJit from tinygrad.helpers import CI, getenv, Context, ProfileRangeEvent, cpu_profile, cpu_events, ProfilePointEvent, dedup from tinygrad.device import Buffer, BufferSpec, Compiled, ProfileDeviceEvent, ProfileGraph...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_softmax_fusion.py
tinygrad_repo/test/test_softmax_fusion.py
import unittest import numpy as np from tinygrad import Tensor, GlobalCounters, Context, Device from tinygrad.dtype import DTypeLike, dtypes from tinygrad.helpers import DEBUG, get_single_element from tinygrad.engine.realize import lower_schedule_item from tinygrad.device import is_dtype_supported def single_kernel_so...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_linearizer.py
tinygrad_repo/test/test_linearizer.py
import numpy as np import unittest from dataclasses import replace from tinygrad.codegen.opt import Opt, OptOps from tinygrad.codegen.gpudims import get_grouped_dims from tinygrad.uop.ops import UOp, Ops, GroupOp from tinygrad.device import Device, Buffer, is_dtype_supported from tinygrad.shape.shapetracker import Sha...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_arange.py
tinygrad_repo/test/test_arange.py
import unittest import numpy as np from tinygrad import Tensor, GlobalCounters, dtypes, nn, Device, Variable from tinygrad.helpers import CI, Context, getenv, RANGEIFY from tinygrad.engine.realize import run_schedule from tinygrad.engine.realize import CompiledRunner, ExecItem, get_program from tinygrad.uop.ops import ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_image_dtype.py
tinygrad_repo/test/test_image_dtype.py
import unittest import numpy as np from tinygrad import Device, dtypes, Tensor, Context from tinygrad.device import LRUAllocator, is_dtype_supported from tinygrad.dtype import ImageDType from tinygrad.engine.realize import lower_schedule from tinygrad.helpers import prod, unwrap from test.helpers import REAL_DEV IMAGE...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_uops_stats.py
tinygrad_repo/test/test_uops_stats.py
import unittest from tinygrad import Tensor from tinygrad.helpers import getenv, GlobalCounters, EMULATE from tinygrad.engine.realize import lower_schedule_item, ProgramSpec, get_program from tinygrad.renderer import Estimates from tinygrad.codegen import full_rewrite from tinygrad.uop.ops import Ops, UOp from tinygrad...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/test_gc.py
tinygrad_repo/test/test_gc.py
#!/usr/bin/env python import gc, inspect import unittest import numpy as np from tinygrad.device import Buffer from tinygrad.engine.realize import run_schedule from tinygrad.uop.ops import UOp from tinygrad.tensor import Tensor def tensors_allocated(): gc.collect() return sum([isinstance(x, Tensor) for x in gc.get...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/speed/external_test_speed_v_torch.py
tinygrad_repo/test/speed/external_test_speed_v_torch.py
import os os.environ["NVIDIA_TF32_OVERRIDE"] = "0" os.environ["MKL_NUM_THREADS"] = "1" os.environ["NUMEXPR_NUM_THREADS"] = "1" os.environ["OMP_NUM_THREADS"] = "1" os.environ["VECLIB_MAXIMUM_THREADS"] = "1" import unittest import torch torch.set_num_threads(1) import time import numpy as np np.set_printoptions(linewidth...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/speed/external_test_specific_conv.py
tinygrad_repo/test/speed/external_test_specific_conv.py
import unittest from tinygrad.helpers import CI from tinygrad import Tensor, Device, dtypes from tinygrad.device import is_dtype_supported # similar to test/external/external_test_gpu_ast.py, but universal @unittest.skipIf(Device.DEFAULT in {"CUDA", "NV"} and CI, "slow on CUDA CI") class TestSpecific(unittest.TestCase...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/speed/external_test_copy_speed.py
tinygrad_repo/test/speed/external_test_copy_speed.py
import unittest, numpy as np from tinygrad import Tensor, Device, TinyJit from tinygrad.helpers import Timing, CI, OSX, getenv import multiprocessing.shared_memory as shared_memory N = getenv("NSZ", 256) class TestCopySpeed(unittest.TestCase): @classmethod def setUpClass(cls): Device[Device.DEFAULT].synchronize() ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/speed/external_test_device_speed.py
tinygrad_repo/test/speed/external_test_device_speed.py
import unittest from tinygrad import Device from tinygrad.helpers import Timing, Profiling class TestDeviceSpeed(unittest.TestCase): @classmethod def setUpClass(cls): cls.dev = Device[Device.DEFAULT] cls.empty = Device[Device.DEFAULT].renderer.render([]) def test_empty_compile(self): with Timing("co...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/device/test_hcq_iface.py
tinygrad_repo/test/device/test_hcq_iface.py
import unittest, array, time from tinygrad.helpers import mv_address from tinygrad.runtime.support.hcq import MMIOInterface from tinygrad.runtime.support.usb import USBMMIOInterface from test.mockgpu.usb import MockUSB class TestHCQIface(unittest.TestCase): def setUp(self): self.size = 4 << 10 self.buffer = ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/device/test_hcq.py
tinygrad_repo/test/device/test_hcq.py
import unittest, ctypes, struct, os, random, numpy as np from tinygrad import Device, Tensor, dtypes from tinygrad.helpers import getenv, CI, mv_address, DEBUG from tinygrad.device import Buffer, BufferSpec from tinygrad.runtime.support.hcq import HCQCompiled, HCQBuffer from tinygrad.runtime.autogen import libc from ti...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/device/test_amd_llvm.py
tinygrad_repo/test/device/test_amd_llvm.py
import unittest import numpy as np from tinygrad import Device from tinygrad.device import CompileError from tinygrad.helpers import flat_mv if Device.DEFAULT=="AMD": from tinygrad.runtime.ops_amd import AMDAllocator, AMDDevice, AMDProgram from tinygrad.runtime.support.compiler_amd import AMDLLVMCompiler @unittest...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/device/test_ocl.py
tinygrad_repo/test/device/test_ocl.py
import unittest from tinygrad import Device from tinygrad.device import Buffer from tinygrad.dtype import dtypes from tinygrad.helpers import CI from tinygrad.runtime.ops_cl import CLDevice, CLAllocator, CLCompiler, CLProgram @unittest.skipUnless(Device.DEFAULT == "CL", "Runs only on OpenCL") class TestCLError(unittes...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/device/test_metal.py
tinygrad_repo/test/device/test_metal.py
import unittest from tinygrad.device import CompileError, Device, Compiler if Device.DEFAULT=="METAL": from tinygrad.runtime.ops_metal import MetalDevice, MetalCompiler, MetalProgram @unittest.skipIf(Device.DEFAULT!="METAL", "Metal support required") class TestMetal(unittest.TestCase): def test_alloc_oom(self): ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/testextra/test_export_model.py
tinygrad_repo/test/testextra/test_export_model.py
import unittest from extra.export_model import export_model, EXPORT_SUPPORTED_DEVICE from tinygrad.tensor import Tensor, Device from tinygrad import dtypes import json class MockMultiInputModel: def forward(self, x1, x2, x3): return x1 + x2 + x3 class MockMultiOutputModel: def __call__(self, x1): return x...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/testextra/test_mockgpu.py
tinygrad_repo/test/testextra/test_mockgpu.py
from tinygrad.helpers import getenv import unittest, importlib @unittest.skipUnless(getenv("MOCKGPU"), 'Testing mockgpu') class TestMockGPU(unittest.TestCase): # https://github.com/tinygrad/tinygrad/pull/7627 def test_import_typing_extensions(self): import test.mockgpu.mockgpu # noqa: F401 # pylint: disable=u...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/testextra/test_bench_log.py
tinygrad_repo/test/testextra/test_bench_log.py
import unittest, time from unittest.case import skipIf from extra.bench_log import BenchEvent, InstantBenchEvent, WallTimeEvent, KernelTimeEvent, log_event_instant, _events, clear_events from tinygrad.helpers import Context, CI from tinygrad.tensor import Tensor from tinygrad.device import Device class TestBenchLog(u...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/testextra/test_lr_scheduler.py
tinygrad_repo/test/testextra/test_lr_scheduler.py
import numpy as np import torch import unittest from tinygrad.tensor import Tensor from tinygrad.nn.state import get_parameters from tinygrad.nn.optim import Adam, SGD from tinygrad.helpers import DEBUG from extra.lr_scheduler import MultiStepLR, ReduceLROnPlateau, CosineAnnealingLR, OneCycleLR from extra.training impo...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/testextra/test_f16_decompress.py
tinygrad_repo/test/testextra/test_f16_decompress.py
import unittest from extra.f16_decompress import u32_to_f16 from tinygrad.tensor import Tensor from tinygrad.device import is_dtype_supported from tinygrad import dtypes import numpy as np class TestF16Decompression(unittest.TestCase): @unittest.skipUnless(is_dtype_supported(dtypes.float16), "need float16") def te...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/testextra/__init__.py
tinygrad_repo/test/testextra/__init__.py
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/opt/test_gen_float4.py
tinygrad_repo/test/opt/test_gen_float4.py
import unittest from tinygrad import Device, Tensor, dtypes from tinygrad.uop.ops import UOp, Ops from tinygrad.codegen.opt import Opt, OptOps from tinygrad.shape.shapetracker import ShapeTracker, View from tinygrad.engine.realize import get_program from tinygrad.helpers import AMX @unittest.skipUnless(Device[Device.D...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/opt/test_tensor_cores.py
tinygrad_repo/test/opt/test_tensor_cores.py
import numpy as np import unittest from dataclasses import replace from tinygrad import Device, Tensor, dtypes from tinygrad.tensor import _to_np_dtype from tinygrad.uop.ops import Ops from tinygrad.dtype import DType from tinygrad.device import is_dtype_supported from tinygrad.helpers import AMX, CI, AMD_LLVM, CPU_LL...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/opt/test_kernel_opts.py
tinygrad_repo/test/opt/test_kernel_opts.py
import unittest from tinygrad import Device, Tensor, dtypes from tinygrad.helpers import CI from tinygrad.codegen.opt import Opt, OptOps, KernelOptError # TODO: write a clean version of this from test.test_linearizer import helper_linearizer_opt class TestKernelOpts(unittest.TestCase): @unittest.skipUnless(Device[D...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_waifu2x.py
tinygrad_repo/test/models/test_waifu2x.py
#!/usr/bin/env python import pathlib import unittest import numpy as np from tinygrad.tensor import Tensor class TestVGG7(unittest.TestCase): def test_vgg7(self): from examples.vgg7_helpers.waifu2x import Vgg7, image_load # Create in tinygrad Tensor.manual_seed(1337) mdl = Vgg7() mdl.load_from_p...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_end2end.py
tinygrad_repo/test/models/test_end2end.py
import torch from torch import nn import unittest import numpy as np from tinygrad.nn.state import get_parameters, get_state_dict from tinygrad.nn import optim, Linear, Conv2d, BatchNorm2d from tinygrad.tensor import Tensor from extra.datasets import fetch_mnist from tinygrad.helpers import CI def compare_tiny_torch(m...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_rnnt.py
tinygrad_repo/test/models/test_rnnt.py
#!/usr/bin/env python import unittest from tinygrad import Tensor from extra.models.rnnt import LSTM import numpy as np import torch class TestRNNT(unittest.TestCase): def test_lstm(self): BS, SQ, IS, HS, L = 2, 20, 40, 128, 2 # create in torch with torch.no_grad(): torch_layer = torch.nn.LSTM(IS,...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_mnist.py
tinygrad_repo/test/models/test_mnist.py
#!/usr/bin/env python import unittest import numpy as np from tinygrad import Tensor, Device from tinygrad.helpers import CI from tinygrad.nn.state import get_parameters from tinygrad.nn import optim, BatchNorm2d from extra.training import train, evaluate from extra.datasets import fetch_mnist # load the mnist dataset...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_real_world.py
tinygrad_repo/test/models/test_real_world.py
import unittest, time, gc import numpy as np from tinygrad.device import is_dtype_supported from tinygrad.nn import optim from tinygrad.nn.state import get_parameters from tinygrad.engine.jit import TinyJit from tinygrad import Tensor, Device, GlobalCounters, dtypes, Variable from tinygrad.helpers import CI, Context fr...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_onnx.py
tinygrad_repo/test/models/test_onnx.py
#!/usr/bin/env python import unittest import numpy as np from tinygrad.frontend.onnx import OnnxRunner from tinygrad.device import Device from tinygrad.helpers import fetch, Context from extra.onnx_helpers import validate from extra.huggingface_onnx.huggingface_manager import DOWNLOADS_DIR, snapshot_download_with_retr...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_whisper.py
tinygrad_repo/test/models/test_whisper.py
import unittest import pathlib from examples.whisper import init_whisper, load_file_waveform, transcribe_file, transcribe_waveform from tinygrad.helpers import CI, fetch, CPU_LLVM from tinygrad import Device, dtypes from tinygrad.device import is_dtype_supported # Audio generated with the command on MacOS: # say "Coul...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/__init__.py
tinygrad_repo/test/models/__init__.py
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_bert.py
tinygrad_repo/test/models/test_bert.py
#!/usr/bin/env python import unittest from tinygrad import Tensor import numpy as np import torch def get_question_samp(bsz, seq_len, vocab_size, seed): np.random.seed(seed) in_ids= np.random.randint(vocab_size, size=(bsz, seq_len)) mask = np.random.choice([True, False], size=(bsz, seq_len)) seg_ids = np.rando...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_resnet.py
tinygrad_repo/test/models/test_resnet.py
import unittest from extra.models import resnet class TestResnet(unittest.TestCase): def test_model_load(self): model = resnet.ResNet18() model.load_from_pretrained() model = resnet.ResNeXt50_32X4D() model.load_from_pretrained() def test_model_load_no_fc_layer(self): model = resnet.ResNet18(n...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_train.py
tinygrad_repo/test/models/test_train.py
import unittest, time import numpy as np from tinygrad import Device from tinygrad.nn.state import get_parameters from tinygrad.nn import optim from tinygrad.helpers import getenv, CI from extra.training import train from extra.models.convnext import ConvNeXt from extra.models.efficientnet import EfficientNet from extr...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/models/test_efficientnet.py
tinygrad_repo/test/models/test_efficientnet.py
import ast, pathlib, unittest import numpy as np from PIL import Image from tinygrad import Tensor from tinygrad.helpers import getenv, CI from extra.models.efficientnet import EfficientNet from extra.models.vit import ViT from extra.models.resnet import ResNet50 def _load_labels(): labels_filename = pathlib.Path(...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_cl_half_max.py
tinygrad_repo/test/external/external_cl_half_max.py
from tinygrad.runtime.ops_cl import CLDevice, CLProgram, compile_cl if __name__ == "__main__": dev = CLDevice() lib = compile_cl(""" #pragma OPENCL EXTENSION cl_khr_fp16 : enable __kernel void test(__global half *out, __global half *a, __global half *b) { int gid = get_global_id(0); out[gid] = max(a[gid], b[gi...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_test_amd.py
tinygrad_repo/test/external/external_test_amd.py
import unittest from tinygrad import Device, Tensor from tinygrad.engine.schedule import create_schedule from tinygrad.runtime.ops_amd import AMDDevice class TestAMD(unittest.TestCase): @classmethod def setUpClass(self): TestAMD.d0: AMDDevice = Device["AMD"] TestAMD.a = Tensor([0.,1.], device="AMD").realiz...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_benchmark_hcopt.py
tinygrad_repo/test/external/external_benchmark_hcopt.py
import random from tinygrad.helpers import getenv from tinygrad.codegen.opt.search import beam_search, bufs_from_lin from tinygrad.codegen.opt.heuristic import hand_coded_optimizations from extra.optimization.helpers import load_worlds, ast_str_to_lin, time_linearizer def optimize_kernel(k): # TODO: update this re...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_llm_eval.py
tinygrad_repo/test/external/external_llm_eval.py
# eval for tinygrad.apps.llm import pyarrow.parquet as pq from tinygrad.helpers import fetch, colored from tinygrad.apps.llm import Transformer, SimpleTokenizer, models from tinygrad import Tensor if __name__ == "__main__": dat = fetch("https://huggingface.co/datasets/allenai/ai2_arc/resolve/main/ARC-Challenge/test-...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_test_yolo.py
tinygrad_repo/test/external/external_test_yolo.py
import unittest from pathlib import Path import cv2 from examples.yolov3 import Darknet, infer, show_labels from tinygrad.helpers import fetch chicken_img = cv2.imread(str(Path(__file__).parent.parent / 'models/efficientnet/Chicken.jpg')) car_img = cv2.imread(str(Path(__file__).parent.parent / 'models/efficientnet/c...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_osx_profiling.py
tinygrad_repo/test/external/external_osx_profiling.py
from tinygrad.runtime.ops_cl import CLProgram, CL, CLBuffer from tinygrad import dtypes import time N = 1000000 a = CLBuffer(N, dtypes.float32) b = CLBuffer(N, dtypes.float32) c = CLBuffer(N, dtypes.float32) prg = CLProgram("test", """__kernel void test(__global float *a, __global float *b, __global float *c) { int...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_test_embedding.py
tinygrad_repo/test/external/external_test_embedding.py
from tinygrad.tensor import Tensor from tinygrad.nn import Embedding if __name__ == "__main__": vocab_size = 50257 dim = 128 test = Embedding(vocab_size, dim) ret = test(Tensor([[1,2,3]])).numpy()
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/fuzz_shapetracker_math.py
tinygrad_repo/test/external/fuzz_shapetracker_math.py
import random from tinygrad.helpers import getenv, DEBUG, colored, trange from tinygrad.shape.shapetracker import ShapeTracker from test.external.fuzz_shapetracker import shapetracker_ops from test.external.fuzz_shapetracker import do_permute, do_reshape_split_one, do_reshape_combine_two, do_flip, do_pad from test.unit...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_metal_compile_slow.py
tinygrad_repo/test/external/external_metal_compile_slow.py
# ruff: noqa: E501 from tinygrad import dtypes from tinygrad.helpers import Timing, getenv from tinygrad.codegen.opt.kernel import Opt, OptOps from tinygrad.engine.realize import get_program, CompiledRunner from tinygrad.uop.ops import UOp, Ops, AxisType if __name__ == "__main__": if getenv("TC", 0) == 0: c0 = U...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_debug_metal_sd_conv.py
tinygrad_repo/test/external/external_debug_metal_sd_conv.py
# ruff: noqa: E501 from tinygrad.codegen.opt.kernel import Kernel, Opt, OptOps from tinygrad.dtype import dtypes from tinygrad.engine.realize import CompiledRunner, get_program from tinygrad.codegen.opt.search import bufs_from_lin from tinygrad.uop.ops import UOp, Ops from tinygrad.shape.shapetracker import ShapeTracke...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/external_test_train_gpt2.py
tinygrad_repo/test/external/external_test_train_gpt2.py
# ruff: noqa: E501 import unittest from tinygrad.uop.ops import UOp, Ops from .search import Opt, OptOps from tinygrad.dtype import dtypes from tinygrad.shape.shapetracker import ShapeTracker from tinygrad.shape.view import View from tinygrad.codegen.opt.kernel import Kernel from test.external.fuzz_linearizer import ...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false
ajouatom/openpilot
https://github.com/ajouatom/openpilot/blob/b0eab6e8de2d57522b657426fbb794f2d736c75c/tinygrad_repo/test/external/speed_compare_amd_am.py
tinygrad_repo/test/external/speed_compare_amd_am.py
from tinygrad import Device, dtypes from tinygrad.helpers import getenv, colorize_float, DEBUG from extra.optimization.helpers import load_worlds, ast_str_to_lin from test.external.fuzz_linearizer import get_fuzz_rawbufs from tinygrad.codegen.opt.heuristic import hand_coded_optimizations from tinygrad.codegen.opt.searc...
python
MIT
b0eab6e8de2d57522b657426fbb794f2d736c75c
2026-01-05T07:04:53.428285Z
false